==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/variables_62.js <==
var searchData=
[
  ['b',['b',['../structplplot_1_1__N9.html#a9f68e776f6ef7243bc35e5871aab6383',1,'plplot::_N9::b()'],['../structPLColor.html#aea5b06e2b696b2f99e589ddd594fee34',1,'PLColor::b()'],['../structarc__struct.html#a1f4233061a8d655df47f88e6461b4b1e',1,'arc_struct::b()']]],
  ['backend',['backend',['../classwxPLDevBase.html#a26bdb27d2d2b23b127a1aea8d5e93869',1,'wxPLDevBase']]],
  ['background',['background',['../structGcwPLdev.html#a43f489633394a39b2ebfd7ad92e0c4d5',1,'GcwPLdev']]],
  ['base',['base',['../structEscText.html#a27f50fc8ce09a219b990abc6959073e1',1,'EscText::base()'],['../structswig__octave__class.html#ac6a03dae555a63dbc7751aa1dc1c9e55',1,'swig_octave_class::base()']]],
  ['base3x',['base3x',['../structPLStream.html#a7668dd6c3144f760c74d391fb53accbe',1,'PLStream']]],
  ['base3y',['base3y',['../structPLStream.html#ac6604eb5ffb1439c89b1f40c812f7468',1,'PLStream']]],
  ['base_5fcont',['BASE_CONT',['../classplplot.html#a8ad02f0abe82b2c26d28a9ea608e21c6',1,'plplot::BASE_CONT()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a03e64e4ab90be54223c1e0ffb4da34b5',1,'plplot.core.plplotjavacConstants.BASE_CONT()'],['../namespaceplplotc.html#a8ad0cfa320c20249a5672441c5d41833',1,'plplotc.BASE_CONT()']]],
  ['base_5fday',['base_day',['../structMJDtimeStruct.html#a7a7b02e1fc6ffee218d9ae1b4ad76f18',1,'MJDtimeStruct::base_day()'],['../structTAI__UTC.html#a86a46f8d5627f742cdbd14b0a8d64eae',1,'TAI_UTC::base_day()']]],
  ['base_5fnames',['base_names',['../structswig__lua__class.html#a25f24829385c30c59cec92c91fceca23',1,'swig_lua_class::base_names()'],['../structswig__octave__class.html#a4045c37af980b6aeeb76bc508f1a7560',1,'swig_octave_class::base_names()']]],
  ['basecx',['basecx',['../structPLStream.html#a1cfe7c5e03bfc0b86f2b7890cbc89f18',1,'PLStream']]],
  ['basecy',['basecy',['../structPLStream.html#a777ec80e260e0df42be630ddf2d1f998',1,'PLStream']]],
  ['basename',['BaseName',['../structPLStream.html#aa3615d1af2fac919072ca4e1ec079a95',1,'PLStream']]],
  ['bases',['bases',['../structswig__lua__class.html#a468e2d019d6cff6bbe8fefc8f572420b',1,'swig_lua_class']]],
  ['bb_5fcolor',['bb_color',['../plplot__octave_8h.html#ab0811ae7f1081938a16395cb6db19b56',1,'plplot_octave.h']]],
  ['bb_5fstyle',['bb_style',['../plplot__octave_8h.html#a48a2fc592daaab159641a6cf9eb6ab42',1,'plplot_octave.h']]],
  ['bg_5fcolor',['bg_color',['../plplot__octave_8h.html#ad1ae34d01d315587d6c45a68174b7328',1,'plplot_octave.h']]],
  ['bgcolor',['bgColor',['../structPlFrame.html#a0a649d61c2f65a42fc3451c6c850293d',1,'PlFrame::bgColor()'],['../structGcwPLdev.html#a9d115ed6bbf9a852b96a9ea0ba77e6d9',1,'GcwPLdev::bgcolor()'],['../structXwDev.html#aa175f8852cb1e51b9a7a93a842db0dab',1,'XwDev::bgcolor()']]],
  ['bitmapheight',['bitmapHeight',['../classwxPLplotwindow.html#ad64a93773b50e4de2d709c497f5c9639',1,'wxPLplotwindow']]],
  ['bitmaptype',['bitmapType',['../classwxPLDevBase.html#ab79801f503398a7e85f969f0f0cca2d6',1,'wxPLDevBase']]],
  ['bitmapwidth',['bitmapWidth',['../classwxPLplotwindow.html#a3e7025f011d95a63ea1ece8de54beaa8',1,'wxPLplotwindow']]],
  ['blue',['blue',['../structcdImageStruct.html#aae5d4b64a60d375e5bb1e1a7cc8b3b6f',1,'cdImageStruct']]],
  ['bm_5fheight',['bm_height',['../classwxPLDevBase.html#aafe25a18297412f62a1b0e9368602139',1,'wxPLDevBase']]],
  ['bm_5fwidth',['bm_width',['../classwxPLDevBase.html#a283f43876c9039cb442cb716dcfe80a9',1,'wxPLDevBase']]],
  ['bop_5fdata',['bop_data',['../structPLStream.html#ad60fe1add202f6c12ee8f6e3f4546962',1,'PLStream']]],
  ['bop_5fhandler',['bop_handler',['../structPLStream.html#a570753f4964edc378661c79b56da7458',1,'PLStream']]],
  ['bopcmd',['bopCmd',['../structPlFrame.html#a0015cea9695cf72b89638874148148b2',1,'PlFrame::bopCmd()'],['../structPlPlotter.html#a6e828a8cb52aaad71314661f2cab39d3',1,'PlPlotter::bopCmd()']]],
  ['border',['border',['../structPlFrame.html#ae6cd88baa34aa30ef958d96c5a399336',1,'PlFrame::border()'],['../structPlPlotter.html#a7b947ac76bd574078c465ebf457611d0',1,'PlPlotter::border()'],['../structTkwDev.html#a4cc81954b003b8bfa80c4b4dcfe9f051',1,'TkwDev::border()'],['../structXwDev.html#a566d91035d635b24101552997b479bd5',1,'XwDev::border()']]],
  ['borderwidth',['borderWidth',['../structPlFrame.html#a88adc0ded0381397e89b8f28ab8a68ff',1,'PlFrame::borderWidth()'],['../structPlPlotter.html#a5e53528a880abb2eeba413e7bd370272',1,'PlPlotter::borderWidth()']]],
  ['bounds',['bounds',['../namespacePlframe.html#a48ee994db20d42716265ab5960c67c50',1,'Plframe']]],
  ['boxbb_5fxmax',['boxbb_xmax',['../structPLStream.html#ad7882678b4080b91ab91bdb74759211a',1,'PLStream']]],
  ['boxbb_5fxmin',['boxbb_xmin',['../structPLStream.html#ab37fa0272b8b6680de67e355dfff0f22',1,'PLStream']]],
  ['boxbb_5fymax',['boxbb_ymax',['../structPLStream.html#a7a075f5767e8505ff2ab5d2b0ad03fe1',1,'PLStream']]],
  ['boxbb_5fymin',['boxbb_ymin',['../structPLStream.html#a42239283478e0954e432bfaf0ee569f4',1,'PLStream']]],
  ['bp',['bp',['../structPDFstrm.html#a5c20dd538504c272832b2d06fbafa9ef',1,'PDFstrm']]],
  ['buf',['buf',['../classoctave__swig__packed.html#aafa28d245f66d78713852cec79856a1b',1,'octave_swig_packed::buf()'],['../tclAPI_8c.html#a095f0dd49eb8681e3a9d4632a98bb06e',1,'buf():&#160;tclAPI.c']]],
  ['buffer',['buffer',['../structPDFstrm.html#a5a2125c9b181ce2413fb880b089ba273',1,'PDFstrm::buffer()'],['../plfill_8c.html#ab670e03eef9a6c21f69d1ad25cce325d',1,'buffer():&#160;plfill.c']]],
  ['bufferleng',['bufferleng',['../plfill_8c.html#a7bdd477ac28c7831f20adcae276b133d',1,'plfill.c']]],
  ['buffersize',['buffersize',['../plfill_8c.html#ac3b4ce1692e5a865e1f804cab9a7dad3',1,'plfill.c']]],
  ['bufmax',['bufmax',['../structPDFstrm.html#a29e8d3996ab88bb7906c434e2b8159da',1,'PDFstrm::bufmax()'],['../structPLStream.html#aed8924bacb8ff9e70b92493dcb91b17d',1,'PLStream::bufmax()']]],
  ['button',['button',['../structplplot_1_1__N2.html#a05930baa71b889a734634b1f29df5bec',1,'plplot::_N2::button()'],['../structplplot__types_1_1plgraphicsin.html#a202b56382ed2e8ff9436d96141df68fa',1,'plplot_types::plgraphicsin::button()'],['../structPLGraphicsIn.html#ae17f938017e1c95e5d8cd89ffa836934',1,'PLGraphicsIn::button()']]],
  ['buttoneh',['ButtonEH',['../structPLStream.html#a4e9b2af1783d70f3958424b2ebd2b6e1',1,'PLStream']]],
  ['buttoneh_5fdata',['ButtonEH_data',['../structPLStream.html#a0ebf6193b59ba88317034f0f5421a7cf',1,'PLStream']]],
  ['bytecnt',['bytecnt',['../structPLStream.html#a2bae14e39334897df7684da4a7d319fe',1,'PLStream']]],
  ['bytemax',['bytemax',['../structPLStream.html#afa8cd5d4c8ac54d5308dc548991a3fee',1,'PLStream']]],
  ['bytestoend',['bytestoend',['../structcdImageStruct.html#a60db5d7fa1ab556aa0d4a6724dd1b98c',1,'cdImageStruct']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/variables_62.js <==
var searchData=
[
  ['b',['b',['../structplplot_1_1__N9.html#a9f68e776f6ef7243bc35e5871aab6383',1,'plplot::_N9::b()'],['../structPLColor.html#aea5b06e2b696b2f99e589ddd594fee34',1,'PLColor::b()'],['../structarc__struct.html#a1f4233061a8d655df47f88e6461b4b1e',1,'arc_struct::b()']]],
  ['base',['base',['../structEscText.html#a27f50fc8ce09a219b990abc6959073e1',1,'EscText::base()'],['../structswig__octave__class.html#ac6a03dae555a63dbc7751aa1dc1c9e55',1,'swig_octave_class::base()']]],
  ['base3x',['base3x',['../structPLStream.html#a7668dd6c3144f760c74d391fb53accbe',1,'PLStream']]],
  ['base3y',['base3y',['../structPLStream.html#ac6604eb5ffb1439c89b1f40c812f7468',1,'PLStream']]],
  ['base_5fcont',['BASE_CONT',['../classplplot.html#a8ad02f0abe82b2c26d28a9ea608e21c6',1,'plplot::BASE_CONT()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a03e64e4ab90be54223c1e0ffb4da34b5',1,'plplot.core.plplotjavacConstants.BASE_CONT()'],['../namespaceplplotc.html#a8ad0cfa320c20249a5672441c5d41833',1,'plplotc.BASE_CONT()']]],
  ['base_5fday',['base_day',['../structMJDtimeStruct.html#a7a7b02e1fc6ffee218d9ae1b4ad76f18',1,'MJDtimeStruct::base_day()'],['../structTAI__UTC.html#a86a46f8d5627f742cdbd14b0a8d64eae',1,'TAI_UTC::base_day()']]],
  ['base_5fnames',['base_names',['../structswig__lua__class.html#a25f24829385c30c59cec92c91fceca23',1,'swig_lua_class::base_names()'],['../structswig__octave__class.html#a4045c37af980b6aeeb76bc508f1a7560',1,'swig_octave_class::base_names()']]],
  ['basecx',['basecx',['../structPLStream.html#a1cfe7c5e03bfc0b86f2b7890cbc89f18',1,'PLStream']]],
  ['basecy',['basecy',['../structPLStream.html#a777ec80e260e0df42be630ddf2d1f998',1,'PLStream']]],
  ['basename',['BaseName',['../structPLStream.html#aa3615d1af2fac919072ca4e1ec079a95',1,'PLStream']]],
  ['bases',['bases',['../structswig__lua__class.html#a468e2d019d6cff6bbe8fefc8f572420b',1,'swig_lua_class']]],
  ['bgcolor',['bgcolor',['../structXwDev.html#aa175f8852cb1e51b9a7a93a842db0dab',1,'XwDev::bgcolor()'],['../structPlFrame.html#a0a649d61c2f65a42fc3451c6c850293d',1,'PlFrame::bgColor()']]],
  ['blue',['blue',['../structcdImageStruct.html#aae5d4b64a60d375e5bb1e1a7cc8b3b6f',1,'cdImageStruct']]],
  ['bop_5fdata',['bop_data',['../structPLStream.html#ad60fe1add202f6c12ee8f6e3f4546962',1,'PLStream']]],
  ['bop_5fhandler',['bop_handler',['../structPLStream.html#a570753f4964edc378661c79b56da7458',1,'PLStream']]],
  ['bopcmd',['bopCmd',['../structPlFrame.html#a0015cea9695cf72b89638874148148b2',1,'PlFrame::bopCmd()'],['../structPlPlotter.html#a6e828a8cb52aaad71314661f2cab39d3',1,'PlPlotter::bopCmd()']]],
  ['border',['border',['../structPlFrame.html#ae6cd88baa34aa30ef958d96c5a399336',1,'PlFrame::border()'],['../structPlPlotter.html#a7b947ac76bd574078c465ebf457611d0',1,'PlPlotter::border()'],['../structTkwDev.html#a4cc81954b003b8bfa80c4b4dcfe9f051',1,'TkwDev::border()'],['../structXwDev.html#a566d91035d635b24101552997b479bd5',1,'XwDev::border()']]],
  ['borderwidth',['borderWidth',['../structPlFrame.html#a88adc0ded0381397e89b8f28ab8a68ff',1,'PlFrame::borderWidth()'],['../structPlPlotter.html#a5e53528a880abb2eeba413e7bd370272',1,'PlPlotter::borderWidth()']]],
  ['bounds',['bounds',['../namespacePlframe.html#a48ee994db20d42716265ab5960c67c50',1,'Plframe']]],
  ['boxbb_5fxmax',['boxbb_xmax',['../structPLStream.html#ad7882678b4080b91ab91bdb74759211a',1,'PLStream']]],
  ['boxbb_5fxmin',['boxbb_xmin',['../structPLStream.html#ab37fa0272b8b6680de67e355dfff0f22',1,'PLStream']]],
  ['boxbb_5fymax',['boxbb_ymax',['../structPLStream.html#a7a075f5767e8505ff2ab5d2b0ad03fe1',1,'PLStream']]],
  ['boxbb_5fymin',['boxbb_ymin',['../structPLStream.html#a42239283478e0954e432bfaf0ee569f4',1,'PLStream']]],
  ['bp',['bp',['../structPDFstrm.html#a5c20dd538504c272832b2d06fbafa9ef',1,'PDFstrm']]],
  ['buf',['buf',['../classoctave__swig__packed.html#aafa28d245f66d78713852cec79856a1b',1,'octave_swig_packed::buf()'],['../tclAPI_8c.html#a095f0dd49eb8681e3a9d4632a98bb06e',1,'buf():&#160;tclAPI.c']]],
  ['buffer',['buffer',['../structPLmDev.html#ad2db6f517d0d7e667f4be48c0b74f908',1,'PLmDev::buffer()'],['../structPDFstrm.html#a5a2125c9b181ce2413fb880b089ba273',1,'PDFstrm::buffer()'],['../structplbuffer.html#a1d1e28dfa615142f22a85a70012d457a',1,'plbuffer::buffer()'],['../plfill_8c.html#ab670e03eef9a6c21f69d1ad25cce325d',1,'buffer():&#160;plfill.c']]],
  ['buffer_5fsize',['buffer_size',['../structPLmDev.html#a730ba640e6aa87b540a660e1ece71c40',1,'PLmDev']]],
  ['bufferleng',['bufferleng',['../plfill_8c.html#a7bdd477ac28c7831f20adcae276b133d',1,'plfill.c']]],
  ['buffersize',['buffersize',['../plfill_8c.html#ac3b4ce1692e5a865e1f804cab9a7dad3',1,'plfill.c']]],
  ['bufmax',['bufmax',['../structPDFstrm.html#a29e8d3996ab88bb7906c434e2b8159da',1,'PDFstrm::bufmax()'],['../structPLStream.html#aed8924bacb8ff9e70b92493dcb91b17d',1,'PLStream::bufmax()']]],
  ['button',['button',['../structplplot_1_1__N2.html#a05930baa71b889a734634b1f29df5bec',1,'plplot::_N2::button()'],['../structplplot__graphics_1_1plgraphicsin.html#a95ef182530332a29736723cf803d9a45',1,'plplot_graphics::plgraphicsin::button()'],['../structPLGraphicsIn.html#ae17f938017e1c95e5d8cd89ffa836934',1,'PLGraphicsIn::button()']]],
  ['buttoneh',['ButtonEH',['../structPLStream.html#a4e9b2af1783d70f3958424b2ebd2b6e1',1,'PLStream']]],
  ['buttoneh_5fdata',['ButtonEH_data',['../structPLStream.html#a0ebf6193b59ba88317034f0f5421a7cf',1,'PLStream']]],
  ['bytecnt',['bytecnt',['../structPLStream.html#a2bae14e39334897df7684da4a7d319fe',1,'PLStream']]],
  ['bytemax',['bytemax',['../structPLStream.html#afa8cd5d4c8ac54d5308dc548991a3fee',1,'PLStream']]],
  ['bytestoend',['bytestoend',['../structcdImageStruct.html#a60db5d7fa1ab556aa0d4a6724dd1b98c',1,'cdImageStruct']]]
];
